Description: Программный комплекс ardj предназначен для создания полностью автоматизированной интернет-радиостанции, управляемой пользователями, с минимальным адмнистрированием или вообще без него. Комплекс позволяет составлять умные плейлисты произвольной сложности, получать звуковые файлы из внешних источников, управлять эфиром через jabber и многое другое. В целом комплекс настроен на создание полностью автономной радиостанции; если вам нужен контроль над плейлистом с точностью до секунды и полностью ручное управление, вам больше подойдёт такое ПО, как SAM Broadcaster или Internet DJ Console. Это руководство содержит всю информацию, необходимую для работы запуска радиостанции, основанной на ardj, и работы с ней. Если при чтении этой документации у вас возникают вопросы, на которые она не отвечает, хотя должна, или если что-то не работает — обращайтесь по адресу hex@umonkey.net.

ardj
|  | След.

# ardj

### Justin Forest

1.2.28

Аннотация

Программный комплекс ardj предназначен для создания полностью автоматизированной интернет-радиостанции, управляемой пользователями, с минимальным адмнистрированием или вообще без него.

Комплекс позволяет составлять умные плейлисты произвольной сложности, получать звуковые файлы из внешних источников, управлять эфиром через jabber и многое другое. В целом комплекс настроен на создание полностью автономной радиостанции; если вам нужен контроль над плейлистом с точностью до секунды и полностью ручное управление, вам больше подойдёт такое ПО, как SAM Broadcaster или Internet DJ Console.

Это руководство содержит всю информацию, необходимую для работы запуска радиостанции, основанной на ardj, и работы с ней.

Если при чтении этой документации у вас возникают вопросы, на которые она не отвечает, хотя должна, или если что-то не работает — обращайтесь по адресу `<hex@umonkey.net>`.

Список примеров

3.1. Настройка доступа к командам jabber-бота
3.2. Автоматическое присвоение статуса администратора
5.1. Общий отчёт о прослушиваниях
5.2. Суточный отчёт о прослушиваниях
6.1. Использование JS-интерфейса WebAPI
B.1. Загрузка музыки из открытых источников
B.2. Создание плейлиста на ходу
B.3. Изменение меток композиции

|  | След.
|  | Глава 1. Архитектура